v6.10.0
=======

Features
--------

- Excluded some items from the project list.


v6.9.0
======

Features
--------

- Implement dark mode for projects.


v6.8.2
======

Bugfixes
--------

- Remove debugging print.


v6.8.1
======

Bugfixes
--------

- Fix typo.


v6.8.0
======

Features
--------

- Allow for 'emphasis' URLs to be provided for the resume.


v6.7.0
======

Features
--------

- Added a projects badge list.


v6.6.0
======

Features
--------

- Require Python 3.8 or later.


Bugfixes
--------

- Repaired honeypot


v6.5.0
======

Features
--------

- Require Python 3.8 or later.


Bugfixes
--------

- Repaired honeypot
